@@ -215,8 +215,6 @@ enum {
   SPVM_BYTECODE_C_CODE_RETURN_DOUBLE,
   SPVM_BYTECODE_C_CODE_RETURN_OBJECT,
   SPVM_BYTECODE_C_CODE_DIE,
-  SPVM_BYTECODE_C_CODE_INC_REF_COUNT,
-  SPVM_BYTECODE_C_CODE_DEC_REF_COUNT,
   SPVM_BYTECODE_C_CODE_WIDE,
 };
 
