@@ -3,10 +3,8 @@
 #include <string.h>
 #include <stdint.h>
 #include <assert.h>
-
 #include <inttypes.h>
 
-
 #include "spvm_compiler.h"
 #include "spvm_array.h"
 #include "spvm_hash.h"
@@ -32,6 +30,12 @@
 #include "spvm_extention.h"
 #include "spvm_extention_bind.h"
 
+
+
+
+
+
+
 const char* const SPVM_OP_C_CODE_NAMES[] = {
   "IF",
   "ELSIF",
@@ -45,7 +49,7 @@ const char* const SPVM_OP_C_CODE_NAMES[] = {
   "NAME",
   "PACKAGE",
   "MY_VAR",
-  "MY_VAR_PROCESS",
+  "MY_VAR_ASSIGN",
   "FIELD",
   "SUB",
   "ENUM",
@@ -108,16 +112,8 @@ const char* const SPVM_OP_C_CODE_NAMES[] = {
   "VOID",
   "TRY",
   "CATCH",
-  "DEC_REF_COUNT",
-  "INC_REF_COUNT",
-  "FORMAL_ARGS",
   "BLOCK_END",
-  "RETURN_PROCESS",
-  "LEAVE_SCOPE",
-  "DIE_PROCESS",
   "STORE",
-  "LAST_PROCESS",
-  "NEXT_PROCESS",
 };
 
 SPVM_OP* SPVM_OP_new_op_use_from_package_name(SPVM_COMPILER* compiler, const char* package_name, const char* file, int32_t line) {
@@ -955,7 +951,7 @@ SPVM_OP* SPVM_OP_build_use(SPVM_COMPILER* compiler, SPVM_OP* op_use, SPVM_OP* op
 SPVM_OP* SPVM_OP_build_my_var(SPVM_COMPILER* compiler, SPVM_OP* op_my_var, SPVM_OP* op_var, SPVM_OP* op_type, SPVM_OP* op_term) {
   
   // Stab
-  SPVM_OP* op_my_var_process = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY_VAR_PROCESS, op_my_var->file, op_my_var->line);
+  SPVM_OP* op_my_var_assign = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY_VAR_ASSIGN, op_my_var->file, op_my_var->line);
   
   // Create my var information
   SPVM_MY_VAR* my_var = SPVM_MY_VAR_new(compiler);
@@ -970,7 +966,7 @@ SPVM_OP* SPVM_OP_build_my_var(SPVM_COMPILER* compiler, SPVM_OP* op_my_var, SPVM_
   op_my_var->uv.my_var = my_var;
   
   // Add my_var op
-  SPVM_OP_sibling_splice(compiler, op_my_var_process, NULL, 0, op_my_var);
+  SPVM_OP_sibling_splice(compiler, op_my_var_assign, NULL, 0, op_my_var);
   
   // Assign
   if (op_term) {
@@ -981,10 +977,10 @@ SPVM_OP* SPVM_OP_build_my_var(SPVM_COMPILER* compiler, SPVM_OP* op_my_var, SPVM_
     SPVM_OP_sibling_splice(compiler, op_assign, NULL, 0, op_var);
     SPVM_OP_sibling_splice(compiler, op_assign, op_var, 0, op_term);
     
-    SPVM_OP_sibling_splice(compiler, op_my_var_process, op_my_var, 0, op_assign);
+    SPVM_OP_sibling_splice(compiler, op_my_var_assign, op_my_var_assign->last, 0, op_assign);
     
-    // Type assumption
-    my_var->op_term_assumption = op_term;
+    // Type inference
+    my_var->op_term_type_inference = op_term;
   }
   
   // Type is none
@@ -992,7 +988,7 @@ SPVM_OP* SPVM_OP_build_my_var(SPVM_COMPILER* compiler, SPVM_OP* op_my_var, SPVM_
     SPVM_yyerror_format(compiler, "\"my %s\" can't detect type at %s line %d\n", my_var->op_name->uv.name, op_my_var->file, op_my_var->line);
   }
   
-  return op_my_var_process;
+  return op_my_var_assign;
 }
 
 SPVM_OP* SPVM_OP_build_field(SPVM_COMPILER* compiler, SPVM_OP* op_field, SPVM_OP* op_name_field, SPVM_OP* op_type) {
@@ -1055,24 +1051,30 @@ SPVM_OP* SPVM_OP_build_sub(SPVM_COMPILER* compiler, SPVM_OP* op_sub, SPVM_OP* op
       SPVM_ARRAY_push(sub->op_args, op_arg->first);
     }
   }
+
+  // Native my vars is same as arguments
+  if (sub->is_native) {
+    SPVM_OP* op_arg = op_args->first;
+    while ((op_arg = SPVM_OP_sibling(compiler, op_arg))) {
+      SPVM_ARRAY_push(sub->op_my_vars, op_arg->first);
+    }
+  }
   
-  // Add my declaration to top of block
+  // Add my declaration to first of block
   if (op_block) {
     SPVM_OP* op_list_statement = op_block->first;
-    SPVM_OP* op_formal_args = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_FORMAL_ARGS, op_list_statement->file, op_list_statement->line);
     {
       int32_t i;
-      for (i = 0; i < sub->op_args->length; i++) {
+      for (i = sub->op_args->length - 1; i >= 0; i--) {
         SPVM_OP* op_arg = SPVM_ARRAY_fetch(sub->op_args, i);
         SPVM_OP* op_my_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY_VAR, op_arg->file, op_arg->line);
         op_my_var->uv.my_var = op_arg->uv.my_var;
-        SPVM_OP* op_my_var_parent = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY_VAR_PROCESS, op_arg->file, op_arg->line);
-        SPVM_OP_sibling_splice(compiler, op_my_var_parent, op_my_var_parent->last, 0, op_my_var);
+        SPVM_OP* op_my_var_assign = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MY_VAR_ASSIGN, op_arg->file, op_arg->line);
+        SPVM_OP_sibling_splice(compiler, op_my_var_assign, op_my_var_assign->last, 0, op_my_var);
         
-        SPVM_OP_sibling_splice(compiler, op_formal_args, op_formal_args->first, 0, op_my_var_parent);
+        SPVM_OP_sibling_splice(compiler, op_list_statement, op_list_statement->first, 0, op_my_var_assign);
       }
     }
-    SPVM_OP_sibling_splice(compiler, op_list_statement, op_list_statement->first, 0, op_formal_args);
   }
   
   // return type
@@ -1211,58 +1213,20 @@ SPVM_OP* SPVM_OP_build_type_name(SPVM_COMPILER* compiler, SPVM_OP* op_name) {
 
 SPVM_OP* SPVM_OP_build_return(SPVM_COMPILER* compiler, SPVM_OP* op_return, SPVM_OP* op_term) {
   
-  SPVM_OP* op_sub_end_process = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_RETURN_PROCESS, op_return->file, op_return->line);
-  
-  SPVM_OP* op_leave_scope = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_LEAVE_SCOPE, op_return->file, op_return->line);
-  
   if (op_term) {
     SPVM_OP_sibling_splice(compiler, op_return, NULL, 0, op_term);
   }
   
-  SPVM_OP_sibling_splice(compiler, op_sub_end_process, op_sub_end_process->last, 0, op_leave_scope);
-  SPVM_OP_sibling_splice(compiler, op_sub_end_process, op_sub_end_process->last, 0, op_return);
-  
-  return op_sub_end_process;
+  return op_return;
 }
 
 SPVM_OP* SPVM_OP_build_die(SPVM_COMPILER* compiler, SPVM_OP* op_die, SPVM_OP* op_term) {
   
-  SPVM_OP* op_die_process = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_DIE_PROCESS, op_die->file, op_die->line);
-  
-  SPVM_OP* op_leave_scope = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_LEAVE_SCOPE, op_die->file, op_die->line);
-  
   if (op_term) {
     SPVM_OP_sibling_splice(compiler, op_die, NULL, 0, op_term);
   }
   
-  SPVM_OP_sibling_splice(compiler, op_die_process, op_die_process->last, 0, op_leave_scope);
-  SPVM_OP_sibling_splice(compiler, op_die_process, op_die_process->last, 0, op_die);
-  
-  return op_die_process;
-}
-
-SPVM_OP* SPVM_OP_build_last(SPVM_COMPILER* compiler, SPVM_OP* op_last) {
-  
-  SPVM_OP* op_last_process = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_LAST_PROCESS, op_last->file, op_last->line);
-  
-  SPVM_OP* op_leave_scope = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_LEAVE_SCOPE, op_last->file, op_last->line);
-  
-  SPVM_OP_sibling_splice(compiler, op_last_process, op_last_process->last, 0, op_leave_scope);
-  SPVM_OP_sibling_splice(compiler, op_last_process, op_last_process->last, 0, op_last);
-  
-  return op_last_process;
-}
-
-SPVM_OP* SPVM_OP_build_next(SPVM_COMPILER* compiler, SPVM_OP* op_next) {
-  
-  SPVM_OP* op_next_process = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_NEXT_PROCESS, op_next->file, op_next->line);
-  
-  SPVM_OP* op_leave_scope = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_LEAVE_SCOPE, op_next->file, op_next->line);
-  
-  SPVM_OP_sibling_splice(compiler, op_next_process, op_next_process->last, 0, op_leave_scope);
-  SPVM_OP_sibling_splice(compiler, op_next_process, op_next_process->last, 0, op_next);
-  
-  return op_next_process;
+  return op_die;
 }
 
 SPVM_OP* SPVM_OP_build_type_array(SPVM_COMPILER* compiler, SPVM_OP* op_type, SPVM_OP* op_term_length) {
