@@ -24,16 +24,6 @@
 
 
 
-
-
-
-
-
-
-
-
-
-
 
 
 
@@ -59,7 +49,7 @@ enum {
   SPVM_OP_C_CODE_NAME,
   SPVM_OP_C_CODE_PACKAGE,
   SPVM_OP_C_CODE_MY_VAR,
-  SPVM_OP_C_CODE_MY_VAR_PROCESS,
+  SPVM_OP_C_CODE_MY_VAR_ASSIGN,
   SPVM_OP_C_CODE_FIELD,
   SPVM_OP_C_CODE_SUB,
   SPVM_OP_C_CODE_ENUM,
@@ -122,16 +112,8 @@ enum {
   SPVM_OP_C_CODE_VOID,
   SPVM_OP_C_CODE_TRY,
   SPVM_OP_C_CODE_CATCH,
-  SPVM_OP_C_CODE_DEC_REF_COUNT,
-  SPVM_OP_C_CODE_INC_REF_COUNT,
-  SPVM_OP_C_CODE_FORMAL_ARGS,
   SPVM_OP_C_CODE_BLOCK_END,
-  SPVM_OP_C_CODE_RETURN_PROCESS,
-  SPVM_OP_C_CODE_LEAVE_SCOPE,
-  SPVM_OP_C_CODE_DIE_PROCESS,
   SPVM_OP_C_CODE_STORE,
-  SPVM_OP_C_CODE_LAST_PROCESS,
-  SPVM_OP_C_CODE_NEXT_PROCESS,
 };
 
 extern const char* const SPVM_OP_C_CODE_NAMES[];
@@ -206,8 +188,6 @@ void SPVM_OP_resolve_type(SPVM_COMPILER* compiler, SPVM_TYPE* type, int32_t name
 void SPVM_OP_resolve_sub_name(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPVM_OP* op_name);
 void SPVM_OP_resolve_field_name(SPVM_COMPILER* compiler, SPVM_OP* op_name);
 
-SPVM_OP* SPVM_OP_build_last(SPVM_COMPILER* compiler, SPVM_OP* op_last);
-SPVM_OP* SPVM_OP_build_next(SPVM_COMPILER* compiler, SPVM_OP* op_next);
 SPVM_OP* SPVM_OP_build_return(SPVM_COMPILER* compiler, SPVM_OP* op_return, SPVM_OP* op_term);
 SPVM_OP* SPVM_OP_build_die(SPVM_COMPILER* compiler, SPVM_OP* op_die, SPVM_OP* op_term);
 SPVM_OP* SPVM_OP_build_try_catch(SPVM_COMPILER* compiler, SPVM_OP* op_try, SPVM_OP* op_try_block, SPVM_OP* op_catch, SPVM_OP* op_my_var, SPVM_OP* op_catch_block);
